==> spip_3.2.11.orig.tar.xz: plugins-dist/porte_plume/lang/barreoutils_en.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/barreoutils?lang_cible=en
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'barre_a_accent_grave' => 'Insert À',
	'barre_adresse' => 'Address',
	'barre_aide' => 'Use the typographic shortcuts to refine your layout',
	'barre_alignerdroite' => '[/Right align/] the paragraph',
	'barre_ancres' => 'Anchors',
	'barre_barre' => 'Strike through the text',
	'barre_bulle' => 'Help bubble',
	'barre_c_cedille_maj' => 'Insert Ç',
	'barre_cadre' => 'Put in a &lt;cadre&gt;textarea&lt;/cadre&gt;',
	'barre_caracteres' => 'Special characters',
	'barre_centrer' => '[|Center|] the paragraph',
	'barre_chercher' => 'Search & Replace',
	'barre_clean' => 'Clean the code of all HTML tags',
	'barre_code' => 'Edit a &lt;code&gt;computer code&lt;/code&gt;',
	'barre_desindenter' => 'Unindent a line',
	'barre_e_accent_aigu' => 'Insert É',
	'barre_e_accent_grave' => 'Insert È',
	'barre_ea' => 'Insert æ',
	'barre_ea_maj' => 'Insert Æ',
	'barre_encadrer' => '[(Frame)] the paragraph',
	'barre_eo' => 'Insert œ',
	'barre_eo_maj' => 'Insert Œ',
	'barre_euro' => 'Insert the € symbol',
	'barre_exposant' => 'Put the text in &lt;sup&gt;superscript&lt;/sup&gt;',
	'barre_formatages_speciaux' => 'Special formating',
	'barre_galerie' => 'Open gallery',
	'barre_gestion_anc_bulle' => 'Anchor help bubble',
	'barre_gestion_anc_caption' => 'Anchors',
	'barre_gestion_anc_cible' => 'Anchor target',
	'barre_gestion_anc_inserer' => 'Convert to anchor',
	'barre_gestion_anc_nom' => 'Anchor name',
	'barre_gestion_anc_pointer' => 'Point to an anchor',
	'barre_gestion_caption' => 'Caption and Summary',
	'barre_gestion_colonne' => 'No. of columns',
	'barre_gestion_cr_casse' => 'Match case',
	'barre_gestion_cr_changercasse' => 'Change case',
	'barre_gestion_cr_changercassemajuscules' => 'Convert to upper case',
	'barre_gestion_cr_changercasseminuscules' => 'Convert to lower case',
	'barre_gestion_cr_chercher' => 'Search',
	'barre_gestion_cr_entier' => 'Only complete words',
	'barre_gestion_cr_remplacer' => 'Replace',
	'barre_gestion_cr_tout' => 'Replace all',
	'barre_gestion_entete' => 'Header',
	'barre_gestion_ligne' => 'No. of lines',
	'barre_gestion_taille' => 'Fixed size',
	'barre_glossaire' => '[?Glossary] reference (Wikipedia)',
	'barre_gras' => '{{Bold}}',
	'barre_guillemets' => 'Place between «double quotes«',
	'barre_guillemets_simples' => 'Place between “single quotes“',
	'barre_indenter' => 'Indent a line',
	'barre_inserer_cadre' => 'Insert a preformatted code (cadre)',
	'barre_inserer_caracteres' => 'Insert special characters',
	'barre_inserer_code' => 'Insert a computer code (code)',
	'barre_intertitre' => 'Turn into a {{{subheading}}}',
	'barre_italic' => '{Italic}',
	'barre_langue' => 'Abbreviated lnguage',
	'barre_lien' => 'Turn into a [hyperlink->http://...]',
	'barre_lien_externe' => 'External link',
	'barre_lien_input' => 'Please enter the target of your hyperlink (you may give an internet URL in the form http://www.mysite.com or else simply the number of an article on this site).',
	'barre_liste_ol' => 'Set numbered list',
	'barre_liste_ul' => 'Set list',
	'barre_lorem_ipsum' => 'Insert a fake paragraph',
	'barre_lorem_ipsum_3' => 'Insert three fake paragraphs',
	'barre_miseenevidence' => '[*Highlight*] the text',
	'barre_note' => 'Turn into a [[Footnote]]',
	'barre_paragraphe' => 'Create a paragraph',
	'barre_petitescapitales' => 'Put the text in &lt;sc&gt;small capitales&lt;/sc&gt;',
	'barre_poesie' => 'Edit as a &lt;poesie&gt;poetry&lt;/poesie&gt;',
	'barre_preview' => 'Preview mode',
	'barre_quote' => '<quote>Quote a message</quote>',
	'barre_stats' => 'Show text statistics',
	'barre_tableau' => 'Insert/modify a table (select it first)',

	// C
	'config_info_enregistree' => 'Configuration saved',

	// E
	'editer' => 'Edit',
	'explication_barre_outils_public' => 'CSS and Javascript Scripts for toolbars
	(Quill extension, Porte Plume) are loaded in the public site and 
	provide toolbars in forums, public crayons or other plugins
	if their respective configurations allow it.',
	'explication_barre_outils_public_2' => 'You can choose not to load these scripts to lighten public pages.
Therefore, whatever configuration the forums, crayons or plugins have, no Quill toolbar will appear automatically in the public site.',

	// I
	'info_barre_outils_public' => 'Public toolbars',
	'info_porte_plume_titre' => 'Toolbars configuration',

	// L
	'label_barre_outils_public_non' => 'Do not load the toolbars scripts in the public site',
	'label_barre_outils_public_oui' => 'Load the toolbars scripts in the public site.',

	// V
	'voir' => 'Preview'
);

==> spip_4.2.9+dfsg.orig.tar.xz: plugins-dist/porte_plume/lang/barreoutils_en.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/barreoutils?lang_cible=en
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'barre_a_accent_grave' => 'Insert À',
	'barre_adresse' => 'Address',
	'barre_aide' => 'Use the typographic shortcuts to refine your layout',
	'barre_alignerdroite' => '[/Right align/] the paragraph',
	'barre_ancres' => 'Anchors',
	'barre_barre' => 'Strike through the text',
	'barre_bulle' => 'Help bubble',
	'barre_c_cedille_maj' => 'Insert Ç',
	'barre_cadre' => 'Put in a &lt;cadre&gt;textarea&lt;/cadre&gt;',
	'barre_caracteres' => 'Special characters',
	'barre_centrer' => '[|Center|] the paragraph',
	'barre_chercher' => 'Search & Replace',
	'barre_clean' => 'Clean the code of all HTML tags',
	'barre_code' => 'Edit a &lt;code&gt;computer code&lt;/code&gt;',
	'barre_desindenter' => 'Unindent a line',
	'barre_e_accent_aigu' => 'Insert É',
	'barre_e_accent_grave' => 'Insert È',
	'barre_ea' => 'Insert æ',
	'barre_ea_maj' => 'Insert Æ',
	'barre_encadrer' => '[(Frame)] the paragraph',
	'barre_eo' => 'Insert œ',
	'barre_eo_maj' => 'Insert Œ',
	'barre_euro' => 'Insert the € symbol',
	'barre_exposant' => 'Put the text in &lt;sup&gt;superscript&lt;/sup&gt;',
	'barre_formatages_speciaux' => 'Special formating',
	'barre_galerie' => 'Open gallery',
	'barre_gestion_anc_bulle' => 'Anchor help bubble',
	'barre_gestion_anc_caption' => 'Anchors',
	'barre_gestion_anc_cible' => 'Anchor target',
	'barre_gestion_anc_inserer' => 'Convert to anchor',
	'barre_gestion_anc_nom' => 'Anchor name',
	'barre_gestion_anc_pointer' => 'Point to an anchor',
	'barre_gestion_caption' => 'Caption and Summary',
	'barre_gestion_colonne' => 'No. of columns',
	'barre_gestion_cr_casse' => 'Match case',
	'barre_gestion_cr_changercasse' => 'Change case',
	'barre_gestion_cr_changercassemajuscules' => 'Convert to upper case',
	'barre_gestion_cr_changercasseminuscules' => 'Convert to lower case',
	'barre_gestion_cr_chercher' => 'Search',
	'barre_gestion_cr_entier' => 'Only complete words',
	'barre_gestion_cr_remplacer' => 'Replace',
	'barre_gestion_cr_tout' => 'Replace all',
	'barre_gestion_entete' => 'Header',
	'barre_gestion_ligne' => 'No. of lines',
	'barre_gestion_taille' => 'Fixed size',
	'barre_glossaire' => '[?Glossary] reference (Wikipedia)',
	'barre_gras' => '{{Bold}}',
	'barre_guillemets' => 'Place between «double quotes«',
	'barre_guillemets_simples' => 'Place between “single quotes“',
	'barre_indenter' => 'Indent a line',
	'barre_inserer_cadre' => 'Insert a preformatted code (```)',
	'barre_inserer_caracteres' => 'Insert special characters',
	'barre_inserer_code' => 'Insert a computer code (`)',
	'barre_intertitre' => 'Turn into a {{{subheading}}}',
	'barre_italic' => '{Italic}',
	'barre_langue' => 'Abbreviated lnguage',
	'barre_lien' => 'Turn into a [hyperlink->http://...]',
	'barre_lien_externe' => 'External link',
	'barre_lien_input' => 'Please enter the target of your hyperlink (you may give an internet URL in the form http://www.mysite.com or else simply the number of an article on this site).',
	'barre_liste_ol' => 'Set numbered list',
	'barre_liste_ul' => 'Set list',
	'barre_lorem_ipsum' => 'Insert a fake paragraph',
	'barre_lorem_ipsum_3' => 'Insert three fake paragraphs',
	'barre_miseenevidence' => '[*Highlight*] the text',
	'barre_note' => 'Turn into a [[Footnote]]',
	'barre_paragraphe' => 'Create a paragraph',
	'barre_petitescapitales' => 'Put the text in &lt;sc&gt;small capitales&lt;/sc&gt;',
	'barre_poesie' => 'Edit as a &lt;poesie&gt;poetry&lt;/poesie&gt;',
	'barre_preview' => 'Preview mode',
	'barre_quote' => '<quote>Quote a message</quote>',
	'barre_stats' => 'Show text statistics',
	'barre_tableau' => 'Insert/modify a table (select it first)',

	// C
	'config_info_enregistree' => 'Configuration saved',

	// E
	'editer' => 'Edit',
	'explication_barre_outils_public' => 'CSS and Javascript Scripts for toolbars
	(Quill extension, Porte Plume) are loaded in the public site and 
	provide toolbars in forums, public crayons or other plugins
	if their respective configurations allow it.',
	'explication_barre_outils_public_2' => 'You can choose not to load these scripts to lighten public pages.
Therefore, whatever configuration the forums, crayons or plugins have, no Quill toolbar will appear automatically in the public site.',

	// I
	'info_barre_outils_public' => 'Public toolbars',
	'info_porte_plume_titre' => 'Toolbars configuration',

	// L
	'label_barre_outils_public_non' => 'Do not load the toolbars scripts in the public site',
	'label_barre_outils_public_oui' => 'Load the toolbars scripts in the public site.',

	// V
	'voir' => 'Preview'
);
